<?php

namespace App\Http\Middleware;

use Closure;
use Tymon\JWTAuth\Exceptions\JWTException;
use Tymon\JWTAuth\Exceptions\TokenExpiredException;
use Tymon\JWTAuth\Facades\JWTAuth;
use Tymon\JWTAuth\Http\Middleware\BaseMiddleware;

class JwtAuthMiddleware
{
    /**
     * Handle an incoming request.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  \Closure $next
     * @return mixed
     */
    public function handle($request, Closure $next)
    {

        try {
            $user = JWTAuth::parseToken()->authenticate();
            if (!verifySign($request->get('sign'), $request->all(), md5($user['id']))) {
                $error = [
                    'message' => '数据验签失败',
                    'code' => 401,
                ];
                return response()->json($error)->setStatusCode(401);
            }

        } catch (TokenExpiredException $e) {
            $error = [
                'message' => 'Token is Expired',
                'code' => 401,
            ];
            return response()->json($error)->setStatusCode(401);
        } catch (TokenInvalidException $e) {
            $error = [
                'message' => $e->getMessage(),
                'code' => 401,
            ];
            return response()->json($error)->setStatusCode(401);
        } catch (JWTException $e) {
            $error = [
                'message' => $e->getMessage(),
                'code' => 401,
            ];
            return response()->json($error)->setStatusCode(401);
        }
        return $next($request);
    }
}
